==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/locales/sr_Latn_XK.php <==
<?php

return [
    'Names' => [
        'bm' => 'bamanankan',
        'bm_ML' => 'bamanankan (Mali)',
        'bn' => 'bangla',
        'bn_BD' => 'bangla (Bangladeš)',
        'bn_IN' => 'bangla (Indija)',
        'cs_CZ' => 'češki (Češka Republika)',
        'en_HK' => 'engleski (SAR Hongkong)',
        'en_KN' => 'engleski (Sveti Kits i Nevis)',
        'en_MO' => 'engleski (SAR Makao)',
        'en_UM' => 'engleski (Manja udaljena ostrva SAD)',
        'en_VC' => 'engleski (Sveti Vinsent i Grenadini)',
        'ff' => 'fulah',
        'ff_CM' => 'fulah (Kamerun)',
        'ff_GN' => 'fulah (Gvineja)',
        'ff_Latn' => 'fulah (latinica)',
        'ff_Latn_BF' => 'fulah (latinica, Burkina Faso)',
        'ff_Latn_CM' => 'fulah (latinica, Kamerun)',
        'ff_Latn_GH' => 'fulah (latinica, Gana)',
        'ff_Latn_GM' => 'fulah (latinica, Gambija)',
        'ff_Latn_GN' => 'fulah (latinica, Gvineja)',
        'ff_Latn_GW' => 'fulah (latinica, Gvineja-Bisao)',
        'ff_Latn_LR' => 'fulah (latinica, Liberija)',
        'ff_Latn_MR' => 'fulah (latinica, Mauritanija)',
        'ff_Latn_NE' => 'fulah (latinica, Niger)',
        'ff_Latn_NG' => 'fulah (latinica, Nigerija)',
        'ff_Latn_SL' => 'fulah (latinica, Sijera Leone)',
        'ff_Latn_SN' => 'fulah (latinica, Senegal)',
        'ff_MR' => 'fulah (Mauritanija)',
        'ff_SN' => 'fulah (Senegal)',
        'fr_CG' => 'francuski (Kongo)',
        'fr_PM' => 'francuski (Sveti Pjer i Mikelon)',
        'fr_RE' => 'francuski (Reunion)',
        'ln_CG' => 'lingala (Kongo)',
        'lo' => 'laoški',
        'lo_LA' => 'laoški (Laos)',
        'pt_CV' => 'portugalski (Kabo Verde)',
        'pt_MO' => 'portugalski (SAR Makao)',
        'si' => 'sinhalski',
        'si_LK' => 'sinhalski (Šri Lanka)',
        'xh' => 'isikosa',
        'xh_ZA' => 'isikosa (Južnoafrička Republika)',
        'zh_HK' => 'kineski (SAR Hongkong)',
        'zh_Hans_HK' => 'kineski (pojednostavljeno kinesko pismo, SAR Hongkong)',
        'zh_Hans_MO' => 'kineski (pojednostavljeno kinesko pismo, SAR Makao)',
        'zh_Hant_HK' => 'kineski (tradicionalno kinesko pismo, SAR Hongkong)',
        'zh_Hant_MO' => 'kineski (tradicionalno kinesko pismo, SAR Makao)',
        'zh_MO' => 'kineski (SAR Makao)',
        'zu' => 'isizulu',
        'zu_ZA' => 'isizulu (Južnoafrička Republika)',
    ],
];

==> symfony_7.4.5+dfsg.orig.tar.xz: symfony-7.4.5/src/Symfony/Component/Intl/Resources/data/locales/sr_Latn_XK.php <==
<?php

return [
    'Names' => [
        'bm' => 'bamanankan',
        'bm_ML' => 'bamanankan (Mali)',
        'bn' => 'bangla',
        'bn_BD' => 'bangla (Bangladeš)',
        'bn_IN' => 'bangla (Indija)',
        'cs_CZ' => 'češki (Češka Republika)',
        'en_CZ' => 'engleski (Češka Republika)',
        'en_HK' => 'engleski (SAR Hongkong)',
        'en_KN' => 'engleski (Sveti Kits i Nevis)',
        'en_MO' => 'engleski (SAR Makao)',
        'en_UM' => 'engleski (Manja udaljena ostrva SAD)',
        'en_VC' => 'engleski (Sveti Vinsent i Grenadini)',
        'ff' => 'fulah',
        'ff_Adlm' => 'fulah (adlam)',
        'ff_Adlm_BF' => 'fulah (adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'fulah (adlam, Kamerun)',
        'ff_Adlm_GH' => 'fulah (adlam, Gana)',
        'ff_Adlm_GM' => 'fulah (adlam, Gambija)',
        'ff_Adlm_GN' => 'fulah (adlam, Gvineja)',
        'ff_Adlm_GW' => 'fulah (adlam, Gvineja-Bisao)',
        'ff_Adlm_LR' => 'fulah (adlam, Liberija)',
        'ff_Adlm_MR' => 'fulah (adlam, Mauritanija)',
        'ff_Adlm_NE' => 'fulah (adlam, Niger)',
        'ff_Adlm_NG' => 'fulah (adlam, Nigerija)',
        'ff_Adlm_SL' => 'fulah (adlam, Sijera Leone)',
        'ff_Adlm_SN' => 'fulah (adlam, Senegal)',
        'ff_CM' => 'fulah (Kamerun)',
        'ff_GN' => 'fulah (Gvineja)',
        'ff_Latn' => 'fulah (latinica)',
        'ff_Latn_BF' => 'fulah (latinica, Burkina Faso)',
        'ff_Latn_CM' => 'fulah (latinica, Kamerun)',
        'ff_Latn_GH' => 'fulah (latinica, Gana)',
        'ff_Latn_GM' => 'fulah (latinica, Gambija)',
        'ff_Latn_GN' => 'fulah (latinica, Gvineja)',
        'ff_Latn_GW' => 'fulah (latinica, Gvineja-Bisao)',
        'ff_Latn_LR' => 'fulah (latinica, Liberija)',
        'ff_Latn_MR' => 'fulah (latinica, Mauritanija)',
        'ff_Latn_NE' => 'fulah (latinica, Niger)',
        'ff_Latn_NG' => 'fulah (latinica, Nigerija)',
        'ff_Latn_SL' => 'fulah (latinica, Sijera Leone)',
        'ff_Latn_SN' => 'fulah (latinica, Senegal)',
        'ff_MR' => 'fulah (Mauritanija)',
        'ff_SN' => 'fulah (Senegal)',
        'fr_CG' => 'francuski (Kongo)',
        'fr_PM' => 'francuski (Sveti Pjer i Mikelon)',
        'fr_RE' => 'francuski (Reunion)',
        'ln_CG' => 'lingala (Kongo)',
        'lo' => 'laoški',
        'lo_LA' => 'laoški (Laos)',
        'pt_CV' => 'portugalski (Kabo Verde)',
        'pt_MO' => 'portugalski (SAR Makao)',
        'si' => 'sinhalski',
        'si_LK' => 'sinhalski (Šri Lanka)',
        'xh' => 'isikosa',
        'xh_ZA' => 'isikosa (Južnoafrička Republika)',
        'zh_HK' => 'kineski (SAR Hongkong)',
        'zh_Hans_HK' => 'kineski (pojednostavljeno kinesko pismo, SAR Hongkong)',
        'zh_Hans_MO' => 'kineski (pojednostavljeno kinesko pismo, SAR Makao)',
        'zh_Hant_HK' => 'kineski (tradicionalno kinesko pismo, SAR Hongkong)',
        'zh_Hant_MO' => 'kineski (tradicionalno kinesko pismo, SAR Makao)',
        'zh_MO' => 'kineski (SAR Makao)',
        'zu' => 'isizulu',
        'zu_ZA' => 'isizulu (Južnoafrička Republika)',
    ],
];
